nautobot.apps - Nautobot Documentation

Skip to content

# `nautobot.apps`

Core app functionality.

## `nautobot.apps.nautobot_database_ready = Signal()` `module-attribute`

Signal sent to all installed apps and plugins after the database is ready.

Specifically this is triggered by the Django built-in `post_migrate` signal, i.e., after `nautobot-server migrate` or `nautobot-server post_upgrade` commands are run.

In other words, this signal is not emitted during the actual server execution; rather it is emitted when setting up the database prior to running the server.

The intended purpose of this signal is for apps and plugins that need to populate or modify the database contents (not the database schema itself!), for example to ensure the existence of certain CustomFields, Jobs, Relationships, etc.

## `nautobot.apps.NautobotAppConfig`

Bases: `NautobotConfig`

Subclass of Django's built-in AppConfig class, to be used for Nautobot plugins.

### `ready()`

Callback after plugin app is loaded.

### `validate(user_config, nautobot_version)` `classmethod`

Validate the user_config for baseline correctness.